@@ -1,33 +1,26 @@
 import json
 import os.path
+import sys
 
 from base64 import b64encode, b64decode
 from Crypto.Cipher import AES
 from Crypto.Random import get_random_bytes
 
-from fire import Fire
-
 
 class Vault:
     """
     Vault is a cyphered dict saved on disk in a single file
-    If vault does not exist, it is automatically created, and 
-    a password is generated.
     """
 
     def __init__(self, password=None, path="vault.db"):
         self.path = path
         self.password = password
         self.vault = None
-        if os.path.exists(path) == False:
-            self.password = self.create()
-            print(f"Vault didn't exists, create {path} with password {self.password}")
 
-            
         if password is not None:
-            self.__load(password, path)
+            self.__load(path=path, password=password)
 
-    def __load(self, password, path):
+    def __load(self, path, password):
         try:
             b64 = ""
             with open(path, "r") as vault_file:
@@ -36,22 +29,28 @@ class Vault:
             nonce = b64decode(b64["nonce"])
             tag = b64decode(b64["tag"])
             data = b64decode(b64["data"])
-            cipher = AES.new(b64decode(self.password), AES.MODE_EAX, nonce=nonce)
+            cipher = AES.new(b64decode(password), AES.MODE_EAX, nonce=nonce)
             raw_data = cipher.decrypt(data)
 
             cipher.verify(tag)
             self.vault = json.loads(raw_data)
 
         except FileNotFoundError:
-            self.create()
+            print(f"Could not load file {path}")
 
     def view(self):
-        print(self.vault)
+        print(json.dumps(self.vault, indent=2))
 
     def keygen(self):
         return b64encode(get_random_bytes(32)).decode()
 
-    def create(self):
+    def create(self, force=False):
+        assert isinstance(force, bool)
+
+        if force is False and os.path.exists(self.path):
+            print("Vault already exists")
+            return None
+
         if self.password is None:
             self.password = self.keygen()
 
@@ -71,6 +70,20 @@ class Vault:
 
         return value
 
+    def load(self, source=None):
+        """
+        Import a json into the vault
+        Args:
+        source if None read for stdin otherwise expects a json filepath
+        """
+        if source is None:
+            source_string = sys.stdin.read()
+        else:
+            source_string = open(source, "r").read()
+
+        self.vault.update(json.loads(source_string))
+        self.save()
+
     def update(self, key, value):
         self.vault.update({key: value})
         self.save()
@@ -93,5 +106,3 @@ class Vault:
         )
         with open(self.path, "w") as vault_file:
             vault_file.write(result)
-
-
